@@ -1,5 +1,5 @@
 import git_sim.git_sim as gs
-import os
+import os, sys
 import argparse
 import pathlib
 import time, datetime
@@ -22,11 +22,13 @@ def main():
     parser.add_argument("--animate", help="Animate the simulation and output as an mp4 video", action="store_true")
     parser.add_argument("--max-branches-per-commit", help="Maximum number of branch labels to display for each commit", type=int, default=1)
     parser.add_argument("--max-tags-per-commit", help="Maximum number of tags to display for each commit", type=int, default=1)
+    parser.add_argument("-d", "--disable-auto-open", help="Disable the automatic opening of the image/video file after generation", action="store_true")
+    parser.add_argument("-r", "--reverse", help="Display commit history in the reverse direction", action="store_true")
 
     subparsers = parser.add_subparsers(dest="subcommand", help="subcommand help")
 
     log = subparsers.add_parser("log", help="log -h")
-    log.add_argument("--commits", help="The number of commits to display in the simulated log output", type=int, default=8, choices=range(1,13))
+    log.add_argument("--commits", help="The number of commits to display in the simulated log output", type=int, default=5, choices=range(1,13))
 
     status = subparsers.add_parser("status", help="status -h")
 
@@ -68,6 +70,10 @@ def main():
     cherrypick = subparsers.add_parser("cherry-pick", help="cherry-pick -h")
     cherrypick.add_argument("commit", nargs=1, type=str, help="The ref (branch/tag), or commit ID to simulate cherry-pick onto active branch")
 
+    if len(sys.argv) == 1:
+        parser.print_help()
+        sys.exit(1)
+
     args = parser.parse_args()
 
     config.media_dir = os.path.join(args.media_dir, "git-sim_media")
@@ -91,13 +97,14 @@ def main():
             image_file_path = os.path.join(os.path.join(config.media_dir, "images"), image_file_name)
             cv2.imwrite(image_file_path, image)
 
-    try:
-        if not args.animate:
-            open_media_file(image_file_path)
-        else:
-            open_media_file(scene.renderer.file_writer.movie_file_path)
-    except FileNotFoundError:
-        print("Error automatically opening video player, please manually open the video file to view animation.")
+    if not args.disable_auto_open:
+        try:
+            if not args.animate:
+                open_media_file(image_file_path)
+            else:
+                open_media_file(scene.renderer.file_writer.movie_file_path)
+        except FileNotFoundError:
+            print("Error automatically opening media, please manually open the image or video file to view.")
 
 if __name__ == "__main__":
     main()
