@@ -141,9 +141,9 @@ class GitSimBaseCommand():
             circle.shift(shift)
 
         if prevCircle:
-            circle.next_to(prevCircle, RIGHT, buff=1.5)
+            circle.next_to(prevCircle, RIGHT if self.scene.args.reverse else LEFT, buff=1.5)
 
-        start = prevCircle.get_center() if prevCircle else LEFT
+        start = prevCircle.get_center() if prevCircle else ( LEFT if self.scene.args.reverse else RIGHT )
         end = circle.get_center()
 
         if commit == "dark":
@@ -185,7 +185,7 @@ class GitSimBaseCommand():
             commitMessage = ""
         else:
             commitId = Text(commit.hexsha[0:6], font="Monospace", font_size=20, color=self.scene.fontColor)
-            commitMessage = commit.message[:40].replace("\n", " ")
+            commitMessage = commit.message.split("\n")[0][:40].replace("\n", " ")
         return commitId, commitMessage, commit, hide_refs
 
     def draw_head(self, commit, commitId):
@@ -253,28 +253,31 @@ class GitSimBaseCommand():
         
         for tag in self.repo.tags:
 
-            if ( commit.hexsha == tag.commit.hexsha ):
-                tagText = Text(tag.name, font="Monospace", font_size=20, color=self.scene.fontColor)
-                tagRec = Rectangle(color=YELLOW, fill_color=YELLOW, fill_opacity=0.25, height=0.4, width=tagText.width+0.25)
+            try:
+                if ( commit.hexsha == tag.commit.hexsha ):
+                    tagText = Text(tag.name, font="Monospace", font_size=20, color=self.scene.fontColor)
+                    tagRec = Rectangle(color=YELLOW, fill_color=YELLOW, fill_opacity=0.25, height=0.4, width=tagText.width+0.25)
 
-                tagRec.next_to(self.prevRef, UP) 
-                tagText.move_to(tagRec.get_center())
+                    tagRec.next_to(self.prevRef, UP) 
+                    tagText.move_to(tagRec.get_center())
 
-                self.prevRef = tagRec
+                    self.prevRef = tagRec
 
-                if self.scene.args.animate:
-                    self.scene.play(Create(tagRec), Create(tagText), run_time=1/self.scene.args.speed)
-                else:
-                    self.scene.add(tagRec, tagText)
+                    if self.scene.args.animate:
+                        self.scene.play(Create(tagRec), Create(tagText), run_time=1/self.scene.args.speed)
+                    else:
+                        self.scene.add(tagRec, tagText)
 
-                self.toFadeOut.add(tagRec, tagText)
+                    self.toFadeOut.add(tagRec, tagText)
 
-                if self.i == 0:
-                    self.topref = self.prevRef
+                    if self.i == 0:
+                        self.topref = self.prevRef
 
-                x += 1
-                if x >= self.scene.args.max_tags_per_commit:
-                    return
+                    x += 1
+                    if x >= self.scene.args.max_tags_per_commit:
+                        return
+            except ValueError:
+                pass
 
     def draw_arrow(self, prevCircle, arrow):
         if prevCircle: 
@@ -444,7 +447,7 @@ class GitSimBaseCommand():
     def setup_and_draw_parent(self, child, commitMessage="New commit", shift=numpy.array([0., 0., 0.]), draw_arrow=True):
         circle = Circle(stroke_color=RED, fill_color=RED, fill_opacity=0.25)
         circle.height = 1 
-        circle.next_to(self.drawnCommits[child.hexsha], LEFT, buff=1.5)
+        circle.next_to(self.drawnCommits[child.hexsha], LEFT if self.scene.args.reverse else RIGHT, buff=1.5)
         circle.shift(shift)
 
         start = circle.get_center()
@@ -456,7 +459,7 @@ class GitSimBaseCommand():
         commitId = Text("abcdef", font="Monospace", font_size=20, color=self.scene.fontColor).next_to(circle, UP) 
         self.toFadeOut.add(commitId)
 
-        commitMessage = commitMessage[:40].replace("\n", " ")
+        commitMessage = commitMessage.split("\n")[0][:40].replace("\n", " ")
         message = Text('\n'.join(commitMessage[j:j+20] for j in range(0, len(commitMessage), 20))[:100], font="Monospace", font_size=14, color=self.scene.fontColor).next_to(circle, DOWN)
         self.toFadeOut.add(message)
 
@@ -476,6 +479,8 @@ class GitSimBaseCommand():
                 self.scene.add(arrow)
             self.toFadeOut.add(arrow)
 
+        return commitId
+
     def draw_arrow_between_commits(self, startsha, endsha):
         start = self.drawnCommits[startsha].get_center()
         end = self.drawnCommits[endsha].get_center()
