@@ -1,14 +1,16 @@
 from manim import *
-from git_sim_base_command import GitSimBaseCommand
+from git_sim.git_sim_base_command import GitSimBaseCommand
 import git, sys, numpy
 
 class GitSimStatus(GitSimBaseCommand):
     def __init__(self, scene):
         super().__init__(scene)
         self.maxrefs = 2
+        self.selected_branches.append(self.repo.active_branch.name)
+        self.hide_first_tag = True
 
     def execute(self):
-        print("Simulating: git status")
+        print("Simulating: git " + self.scene.args.subcommand)
 
         self.show_intro()
         self.get_commits()
